.. ajdmom documentation master file, created by
   sphinx-quickstart on Fri May 19 17:16:26 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

AJD Moment Derivation
=============================================================

AJD: Affine Jump Diffusion -----------------------------
``ajdmom`` (AJD **mom**\ ents) 
*Release* v1.0

**AJDmom** is a Python Package for auto-deriving the moment and covariance
formulas for some :abbr:`AJD(Affine Jump Diffusion)` processes, such as 
the well-known Heston :abbr:`SV(Stochastic Volatility)` model and its AJD
extensions.


The User Guide
---------------

.. toctree::
   :maxdepth: 2

   usage
   theory
   design
   api
   1fsv
   1fsvj
   2fsv
   2fsvj


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
